# -*- coding: utf-8 -*-
# (c) 2014-2018 The mqttwarn developers

__version__   = '0.14.0'

__author__    = 'Jan-Piet Mens <jpmens()gmail.com>, Ben Jones <ben.jones12()gmail.com>'
__copyright__ = 'Copyright 2014-2018 Jan-Piet Mens'
__license__   = 'Eclipse Public License - v 2.0 (http://www.eclipse.org/legal/epl-2.0/)'
